@@ -8,6 +8,7 @@ package main
 
 import (
 	"fmt"
+	"io"
 	"io/fs"
 	"os"
 	"os/exec"
@@ -26,8 +27,13 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
+var (
+	filename           = "VERSION"
+	stdout   io.Writer = os.Stdout
+)
+
 func main() {
-	// this is a workaround for the man helper getting accidentially
+	// this is a workaround for the man helper getting accidentally
 	// installed into my $GOBIN dir and me not being able to figure out
 	// why. So instead of being greeted with an ugly panic message
 	// every now and then when I need to open a man page I decided
@@ -48,7 +54,7 @@ func main() {
 		return
 	}
 
-	vs, err := os.ReadFile("VERSION")
+	vs, err := os.ReadFile(filename)
 	if err != nil {
 		panic(err)
 	}
@@ -74,7 +80,7 @@ func main() {
 	funcMap := template.FuncMap{
 		"flags": getFlags,
 	}
-	if err := template.Must(template.New("man").Funcs(funcMap).Parse(manTpl)).Execute(os.Stdout, data); err != nil {
+	if err := template.Must(template.New("man").Funcs(funcMap).Parse(manTpl)).Execute(stdout, data); err != nil {
 		panic(err)
 	}
 }
