@@ -4,8 +4,8 @@ import (
 	"fmt"
 
 	"github.com/gopasspw/gopass/internal/backend"
-	"github.com/gopasspw/gopass/internal/set"
 	"github.com/gopasspw/gopass/pkg/debug"
+	"github.com/gopasspw/gopass/pkg/set"
 	"github.com/urfave/cli/v2"
 )
 
@@ -32,6 +32,10 @@ func ShowFlags() []cli.Flag {
 			Name:  "qr",
 			Usage: "Print the password as a QR Code",
 		},
+		&cli.BoolFlag{
+			Name:  "qrbody",
+			Usage: "Print the body as a QR Code",
+		},
 		&cli.BoolFlag{
 			Name:    "unsafe",
 			Aliases: []string{"u", "force", "f"},
@@ -332,6 +336,11 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"u", "force", "f"},
 					Usage:   "In the case of an exact match, display the password even if safecontent is enabled",
 				},
+				&cli.BoolFlag{
+					Name:    "regex",
+					Aliases: []string{"r"},
+					Usage:   "Interpret pattern as regular expression",
+				},
 			},
 		},
 		{
@@ -658,7 +667,11 @@ func (s *Action) GetCommands() []*cli.Command {
 					Usage:   "Mount a password store",
 					Description: "" +
 						"This command allows for mounting an existing or new password store " +
-						"at any path in an existing root store.",
+						"at any path in an existing root store." +
+						"\n\n" +
+						"For example: gopass mounts add secondary-store /path/to/existing/store" +
+						"\n\n" +
+						"Learn more: https://github.com/gopasspw/gopass/blob/master/docs/commands/mounts.md",
 					Before: s.IsInitialized,
 					Action: s.MountAdd,
 					Flags: []cli.Flag{
@@ -714,6 +727,11 @@ func (s *Action) GetCommands() []*cli.Command {
 					Aliases: []string{"q"},
 					Usage:   "Write QR code to FILE",
 				},
+				&cli.BoolFlag{
+					Name:    "chained",
+					Aliases: []string{"p"},
+					Usage:   "chain the token to the password",
+				},
 				&cli.BoolFlag{
 					Name:    "password",
 					Aliases: []string{"o"},
