@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"strings"
 
 	"github.com/fatih/color"
 	"github.com/gopasspw/gopass/internal/action/exit"
@@ -140,30 +141,34 @@ func (s *Action) initGenerateIdentity(ctx context.Context, crypto backend.Crypto
 		if err != nil {
 			return err
 		}
+		if strings.TrimSpace(email) == "" {
+			return fmt.Errorf("⛔️ Please enter a valid email address to proceed")
+		}
 	}
 
 	passphrase := xkcdgen.Random()
 	pwGenerated := true
-	want, err := termio.AskForBool(ctx, "⚠ Do you want to enter a passphrase? (otherwise we generate one for you)", false)
-	if err != nil {
-		return err
-	}
-	if want {
-		pwGenerated = false
-		sv, err := termio.AskForPassword(ctx, "passphrase for your new keypair", true)
-		if err != nil {
-			return fmt.Errorf("failed to read passphrase: %w", err)
-		}
-		passphrase = sv
-	}
-
 	// support fully automated setup (e.g. for tests)
-	if !ctxutil.IsInteractive(ctx) && ctxutil.HasPasswordCallback(ctx) {
+	//nolint:nestif
+	if ctxutil.HasPasswordCallback(ctx) {
 		pw, err := ctxutil.GetPasswordCallback(ctx)("", true)
 		if err == nil {
 			passphrase = string(pw)
 		}
 		pwGenerated = false
+	} else {
+		want, err := termio.AskForBool(ctx, "⚠ Do you want to enter a passphrase? (otherwise we generate one for you)", false)
+		if err != nil {
+			return err
+		}
+		if want {
+			pwGenerated = false
+			sv, err := termio.AskForPassword(ctx, "passphrase for your new keypair", true)
+			if err != nil {
+				return fmt.Errorf("failed to read passphrase: %w", err)
+			}
+			passphrase = sv
+		}
 	}
 
 	if crypto.Name() == "gpgcli" {
@@ -176,17 +181,22 @@ func (s *Action) initGenerateIdentity(ctx context.Context, crypto backend.Crypto
 		}
 	}
 
+	if pwGenerated {
+		out.Printf(ctx, color.MagentaString("Passphrase: ")+passphrase)
+		out.Noticef(ctx, "You need to remember this very well!")
+
+		// Prompt to confirm that the user noted their passphrase
+		if want, err := termio.AskForBool(ctx, "Did you save your passphrase?", true); err != nil || !want {
+			return fmt.Errorf("user did not confirm saving the passphrase: %w", err)
+		}
+	}
+
 	if err := crypto.GenerateIdentity(ctx, name, email, passphrase); err != nil {
 		return fmt.Errorf("failed to create new private key: %w", err)
 	}
 
 	out.OKf(ctx, "Key pair for %s generated", crypto.Name())
 
-	if pwGenerated {
-		out.Printf(ctx, color.MagentaString("Passphrase: ")+passphrase)
-		out.Noticef(ctx, "You need to remember this very well!")
-	}
-
 	out.Notice(ctx, "🔐 We need to unlock your newly created private key now! Please enter the passphrase you just generated.")
 
 	// avoid the gpg cache or we won't find the newly created key
@@ -319,7 +329,7 @@ func (s *Action) initLocal(ctx context.Context, remote string) error {
 }
 
 func (s *Action) initDetectPassage(ctx context.Context) error {
-	pIds := age.PassageIdFile()
+	pIds := age.PassageIDFile()
 	if !fsutil.IsFile(pIds) {
 		debug.Log("no passage identities found at %s", pIds)
 
